pub struct Timelock {
pub authority: Pubkey,
pub signer_bump: u8,
pub delay_in_slots: u64,
}Fields
signer_bump: u8delay_in_slots: u64Trait Implementations
Sourceimpl AccountDeserialize for Timelock
impl AccountDeserialize for Timelock
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Timelock
impl AccountSerialize for Timelock
Sourceimpl BorshDeserialize for Timelock
impl BorshDeserialize for Timelock
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Timelock
impl BorshSerialize for Timelock
Sourceimpl Discriminator for Timelock
impl Discriminator for Timelock
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]